from magik.internal_logger import logger
from magik.constants import TEST_DIR
from magik.sys_exec import read_from_file, write_to_file
from magik.constants import EXAMPLES_DIR
import inspect


# Get the path of the file within the module
def _get_module_file_path(file_name):
    module = inspect.getmodule(_get_module_file_path)
    module_file_path = inspect.getfile(module)
    module_dir = module_file_path.rpartition("/")[0]  # Extract the directory path
    file_path = module_dir + "/" + file_name  # Combine with the file name
    return file_path


def _generate_example_prompt(test_path):
    example_prompt = "Translate this text from English to French: {text_to_translate}"
    write_to_file(f"{test_path}/prompt.txt", example_prompt)


def _generate_example_assertions(test_path):
    abs_assertions_filepath = _get_module_file_path("./examples/assertions.py")
    example_assertions = read_from_file(abs_assertions_filepath)
    write_to_file(f"{test_path}/assertions.py", example_assertions)


def generate_test(test_name):
    logger.debug(f"Generating test {test_name}...\n")
    test_path = f"{TEST_DIR}/{test_name}"

    _generate_example_prompt(test_path)
    _generate_example_assertions(test_path)
    logger.success(
        f"""Generated test {test_name}
- {test_path}/assertions.py
- {test_path}/prompt.txt
"""
    )
    return 1



from magik.evaluators import (
    contains_any,
    contains_none,
    contains_email,
    contains_all,
)


# Define custom functions here
# Should return { 'result': boolean, 'reason': string }
def is_hallucination(*args):
    # Your logic here
    return {"result": False, "reason": "custom reason."}


# Define tests here
tests = [
    # Test 1: Test that the output does not contain any restricted keywords
    {
        "description": "output does not contain restricted keywords",
        "eval_function": contains_none,
        "eval_function_args": [["AI", "GPT-3"]],
        "prompt_vars": {
            "text_to_translate": "Hello world"  # These will only be used for the prompt in development mode
        },
        "failure_labels": ["contains_restricted_keyword"],
    },
    # Test 2: Test that the output does not contain PII
    {
        "description": "output does not contain email",
        "eval_function": contains_email,
        "eval_function_args": [],
        "prompt_vars": {
            "text_to_translate": "Hello world"  # These will only be used for the prompt in development mode
        },
        "failure_labels": ["pii_leak"],
    },
    # Test 3: Test that the output is accurate and contains all important keywords
    {
        "description": "output contains important keywords",
        "eval_function": contains_all,
        "eval_function_args": ["Bonjour", "Monde"],
        "prompt_vars": {
            "text_to_translate": "Hello world"  # These will only be used for the prompt in development mode
        },
        "failure_labels": ["contains_restricted_keyword"],
    },
    # Test 4: Test the output against a custom function
    {
        "description": "output passed custom_function",
        "eval_function": is_hallucination,
        "eval_function_args": [],
        "prompt_vars": {
            "text_to_translate": "Hello world"  # These will only be used for the prompt in development mode
        },
        "failure_labels": ["hallucination"],
    },
]



from magik.sys_exec import read_json_file
from magik.constants import CONFIG_FILE_PATH


def _load_config():
    return read_json_file(CONFIG_FILE_PATH)


def get_magik_api_key():
    config = _load_config()
    return config.get("MAGIK_API_KEY")


def get_open_ai_api_key():
    config = _load_config()
    return config.get("OPEN_AI_API_KEY")


def get_open_ai_default_model():
    config = _load_config()
    return config.get("OPEN_AI_DEFAULT_MODEL")



import asyncio
import os
import json
import subprocess
from magik.internal_logger import logger


def execute_command(command, confirm=True, log=True):
    if confirm:
        confirmation = input(f"Run '{command}'? (y/n)")
        if confirmation != "y":
            return

    result = subprocess.run(command, shell=True, capture_output=True, text=True)

    if result.returncode == 0:
        if log:
            logger.info(command)
        output = result.stdout
        if log:
            logger.info(output)
        return output
    else:
        if log:
            logger.info(command)
        error = result.stderr
        if log:
            logger.error("error:" + error)
        return error


async def execute_command_async(command, confirm=True, log=True):
    logger.info(f"executing command {command}")
    if confirm:
        confirmation = input(f"Run '{command}'? (y/n)")
        if confirmation != "y":
            return

    # Create a new subprocess, redirect the standard output into a pipe
    process = await asyncio.create_subprocess_shell(
        command, stdout=asyncio.subprocess.PIPE, stderr=asyncio.subprocess.PIPE
    )

    # Read output
    stdout, stderr = await process.communicate()

    if process.returncode == 0:
        if log:
            logger.info(command)
        output = stdout.decode()
        if log:
            logger.info(output)
        return output
    else:
        if log:
            print(command)
        error = stderr.decode()
        if log:
            logger.error("error:" + error)
        return error


def file_exists(filepath):
    return os.path.isfile(filepath)


def create_file(filepath):
    directory = os.path.dirname(filepath)
    os.makedirs(
        directory, exist_ok=True
    )  # Create parent directories if they don't exist
    open(filepath, "a").close()  # Create an empty file at the specified filepath


def touch(file_path, confirm=False):
    execute_command(f"touch {file_path}", confirm=confirm)


def write_to_file(file_path, content):
    directory = os.path.dirname(file_path)

    try:
        # Check if directory exists, create it if necessary
        if not os.path.exists(directory):
            os.makedirs(directory)

        with open(file_path, "w") as file:
            file.write(content)
        logger.debug(f"Successfully wrote to file: {file_path}")
    except IOError as e:
        logger.error(f"Error writing to file: {e}")


def append_to_file(file_path, data):
    write_to_file(file_path, data, mode="a")


def read_from_file(file_path):
    if file_exists(file_path) == False:
        raise Exception(f"File does not exist at {file_path}")
    try:
        with open(file_path, "r") as file:
            data = file.read()
        return data
    except IOError:
        raise Exception(f"Error reading from file: {file_path}")


def read_json_file(file_path):
    data = None
    with open(file_path, "r") as file:
        data = json.load(file)
    return data



# Normalize the output to a testable format
def normalize_output_string(str):
    str = str.replace("\n", "")
    str = str.replace("\t", "")
    str = str.replace("'", "")
    str = str.replace('"', "")
    return str


def substitute_vars(string, vars_dict):
    return string.format(**vars_dict)


def standardize_url(url):
    if url.startswith("http://") or url.startswith("https://"):
        return url
    else:
        return "http://" + url



#!/usr/bin/env python3

import argparse
from magik.initialize import initialize
from magik.generate import generate_test
from magik.deploy import deploy_test
from magik.internal_logger import logger
from magik.run import Run

commands = [
    "init",
    "generate",
    "run",
    "deploy",
]


def main():
    parser = argparse.ArgumentParser(
        description="Generate, run, and deploy unit tests for your AI app"
    )
    parser.add_argument("cmd", help="Command to execute")
    parser.add_argument("test_name", nargs="?", help="Name of the test (optional)")
    parser.add_argument(
        "--prod", action="store_true", help="Flag for production environment"
    )
    parser.add_argument("--start_date", help="Start date (optional)")
    parser.add_argument("--end_date", help="End date (optional)")
    parser.add_argument("--prompt_slug", help="Prompt slug (optional)")

    args = parser.parse_args()
    cmd = args.cmd
    test_name = args.test_name
    is_production = args.prod if hasattr(args, "prod") else False
    start_date = args.start_date
    end_date = args.end_date
    prompt_slug = args.prompt_slug

    if not cmd:
        logger.error("Missing command")
        return

    if cmd not in commands:
        logger.error(f"Error: Command '{cmd}' not found")
        return

    if (cmd in ["generate", "deploy"]) and not test_name:
        logger.info(
            f"Please provide a test_name argument as well.\n\nUsage: magik {cmd} <test_name>"
        )
        return

    if cmd == "init":
        initialize()
        return

    if cmd == "generate":
        generate_test(test_name)
        return

    if cmd == "run" and not is_production:
        test_runner = Run()
        test_runner.run_tests(test_name)
        return

    if cmd == "run" and is_production:
        if not start_date or not end_date:
            logger.info(
                f"Please provide a start_date and end_date argument as well.\n\nUsage: magik run <test_name> --prod --start_date <start_date> --end_date <end_date>"
            )
            return

        test_runner = Run()
        test_runner.run_tests_in_prod(
            start_date=start_date,
            end_date=end_date,
            prompt_slug=prompt_slug,
        )
        return

    if cmd == "deploy":
        deploy_test(test_name)
        return


if __name__ == "__main__":
    main()



import os
import requests
from magik.internal_logger import logger
from magik.constants import CONFIG_FILE_PATH, DEPLOY_URL, TEST_DIR
from magik.config import get_magik_api_key


def deploy_test(test_name: str):
    api_key = get_magik_api_key()
    if api_key == None:
        logger.error(f"No API key found. Please add your API key to {CONFIG_FILE_PATH}")

    # construct the file path
    file_path = f"{TEST_DIR}/{test_name}/assertions.py"

    # check if the file exists
    if not os.path.isfile(file_path):
        logger.info(f"No assertions.py file found for test_name {test_name}")
        return

    # read file
    with open(file_path, "rb") as f:
        file_content = f.read()

    # prepare data for API request
    headers = {"magik-api-key": api_key}
    data = {"testId": test_name}
    files = {"file": ("assertions.py", file_content)}

    # make a POST request to the API
    response = requests.post(DEPLOY_URL, files=files, data=data, headers=headers)

    # check the response
    if response.status_code == 200:
        logger.info(f"Successfully uploaded {file_path}")
    else:
        logger.info(
            f"Failed to upload {file_path}. Status code: {response.status_code}"
        )


def deploy_all(api_key: str):
    # find all test_ids in {TEST_DIR}
    test_names = os.listdir(TEST_DIR)

    for test_name in test_names:
        deploy_test(test_name, api_key)



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

with open("requirements.txt") as f:
    requirements = f.read().splitlines()

setuptools.setup(
    name="magik",
    version="0.1.8",
    author="Magik Labs Team",
    author_email="hello@magiklabs.app",
    description="SDK to write and run tests for your LLM app",
    long_description=long_description,
    long_description_content_type="text/markdown",
    packages=setuptools.find_packages(),
    install_requires=requirements,
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    entry_points={
        "console_scripts": [
            "magik=magik.cli:main",
        ],
    },
    python_requires=">=3.6",
)



import logging
import colorlog


class Singleton(type):
    _instances = {}

    def __call__(cls, *args, **kwargs):
        if cls not in cls._instances:
            cls._instances[cls] = super(Singleton, cls).__call__(*args, **kwargs)
        return cls._instances[cls]


class CLIAppLogger(logging.Logger, metaclass=Singleton):
    def __init__(self, name, level=logging.NOTSET):
        super().__init__(name, level)

        # Create a console handler with color support
        console_handler = colorlog.StreamHandler()
        console_handler.setFormatter(
            colorlog.ColoredFormatter(
                "%(log_color)s%(message)s",
                log_colors={
                    "DEBUG": "cyan",
                    "INFO": "white",
                    "WARNING": "yellow",
                    "ERROR": "red",
                    "CRITICAL": "bold_red",
                },
            )
        )
        self.addHandler(console_handler)

    def success(self, message):
        self.info(f"\033[32m{message}\033[0m")  # Output info log in green

    def error(self, message, *args, **kwargs):
        super().error("ERROR: " + message, *args, **kwargs)

    def warning(self, message, *args, **kwargs):
        super().warning("WARN: " + message, *args, **kwargs)

    def log_with_color(self, message, color, *args, **kwargs):
        colors = {
            "black": "30",
            "red": "31",
            "green": "32",
            "yellow": "33",
            "blue": "34",
            "magenta": "35",
            "cyan": "36",
            "white": "37",
        }

        color_code = colors.get(color.lower(), "37")
        formatted_message = f"\033[{color_code}m{message}\033[0m"
        print(formatted_message, *args, **kwargs)


def setup_logger():
    logger = CLIAppLogger("cli_logger", level=logging.INFO)
    return logger


# Create a default logger instance
logger = setup_logger()



# Contains functions to evaluate assertions.
import requests
import json
import re
import ast
from magik.openai_helper import OpenAI
from magik.utils import standardize_url
from magik.constants import OPEN_AI_DEFAULT_MODEL


def generate_grading_prompt(output_to_evaluate, grading_criteria):
    return (
        """
    You are grading a response string according to a grading criteria given to you.
    
    If the gradient criteria is true, then the test_result is True. Otherwise, it is false.
    
    Explain the reason for the test_result in the reason field.
    
    Respond with a python dictionary object that looks like this:
    {test_result: boolean; reason: string;}
    
    Examples:

    String: Qui est le président des États-Unis?
    Grading Criteria: Contains the french words for 'president' and 'United States'
    {"test_result": True, "reason": "the content contains the word 'world'"}

    String: Earth is the second planet from the sun.
    Grading Criteria: If the fact is true, then the test_result is True. Otherwise, it is false.
    {"test_result": False, "reason": "The string is factually inaccurate - Earth is actually the third planet from the sun."}`
    """
        + f"""
        String: {output_to_evaluate}
        Grading Criteria: {grading_criteria}
    """
    )


# Define the evaluation functions
def equals(
    output_to_test,
    expected_output,
    case_sensitive=False,
):
    if case_sensitive == False:
        output_to_test = output_to_test.lower()
        expected_output = expected_output.lower()
    if output_to_test == expected_output:
        result = True
        reason = "✅ output exactly matches expected output"
    else:
        result = False
        reason = "output does not exactly match expected output"
    return {"result": result, "reason": reason}


def contains_all(output_to_test, keywords, case_sensitive=False):
    if case_sensitive == False:
        output_to_test = output_to_test.lower()
        keywords = list(map(lambda k: k.lower(), keywords))
    missing_keywords = []
    for keyword in keywords:
        if keyword not in output_to_test:
            result = False
            missing_keywords.append(keyword)
    if (len(missing_keywords)) > 0:
        result = False
        reason = f"keywords not found in output: " + ", ".join(missing_keywords)
    else:
        result = True
        reason = f"{len(keywords)}/{len(keywords)} keywords found in output"

    return {"result": result, "reason": reason}


def contains_any(output_to_test, keywords, case_sensitive=False):
    if not case_sensitive:
        output_to_test = output_to_test.lower()
        keywords = list(map(lambda k: k.lower(), keywords))

    found_keywords = []
    for keyword in keywords:
        if keyword in output_to_test:
            found_keywords.append(keyword)

    if found_keywords:
        result = True
        reason = f"One or more keywords were found in output: " + ", ".join(
            found_keywords
        )
    else:
        result = False
        reason = "No keywords found in output"

    return {"result": result, "reason": reason}


def contains_none(output_to_test, keywords, case_sensitive=False):
    if not case_sensitive:
        output_to_test = output_to_test.lower()
        keywords = list(map(lambda k: k.lower(), keywords))

    found_keywords = []
    for keyword in keywords:
        if keyword in output_to_test:
            found_keywords.append(keyword)

    if found_keywords:
        result = False
        reason = f"One or more keywords were found in output: " + ", ".join(
            found_keywords
        )
    else:
        result = True
        reason = "No keywords found in output"

    return {"result": result, "reason": reason}


def negate(output_to_test, eval_function, *args, **kwargs):
    eval_result = eval_function(output_to_test, *args, **kwargs)
    return {
        "result": not eval_result["result"],
        "reason": f"{eval_function.__name__} returned {eval_result['result']} with reason {eval_result['reason']}",
    }


def contains(output_to_test, keyword, case_sensitive=False):
    if case_sensitive == False:
        output_to_test = output_to_test.lower()
        keyword = keyword.lower()
    if keyword not in output_to_test:
        result = False
        reason = f"keyword not found in output: " + keyword
    else:
        result = True
        reason = f"keyword {keyword} found in output"

    return {"result": result, "reason": reason}


def regex(output_to_test, pattern):
    match = re.search(pattern, output_to_test)
    if match:
        return {"result": True, "reason": f"regex pattern {pattern} found in output"}
    else:
        return {
            "result": False,
            "reason": f"regex pattern {pattern} not found in output",
        }


def starts_with(output_to_test, substring, case_sensitive=False):
    if case_sensitive == False:
        output_to_test = output_to_test.lower()
        substring = substring.lower()
    result = output_to_test.startswith(substring)
    if result == True:
        return {"result": result, "reason": "output starts with " + substring}
    else:
        return {"result": result, "reason": "output does not start with " + substring}


def ends_with(output_to_test, substring, case_sensitive=False):
    if case_sensitive == False:
        output_to_test = output_to_test.lower()
        substring = substring.lower()
    result = output_to_test.endswith(substring)
    if result == True:
        return {"result": result, "reason": "output ends with " + substring}
    else:
        return {"result": result, "reason": "output does not end with " + substring}


def grade_using_llm(output_to_test, eval_rubric):
    openai = OpenAI()
    # eval_rubric is a string that contains the rubric by which to evaluate the output
    evaluation_prompt = generate_grading_prompt(output_to_test, eval_rubric)
    llm_response = openai.openai_chat_completion_message(
        model=OPEN_AI_DEFAULT_MODEL, prompt=evaluation_prompt
    )

    # llm_response_dict is a dictionary that contains the response from the LLM
    llm_response_dict = ast.literal_eval(llm_response)

    # result is the true / false value from the LLM
    result = llm_response_dict["test_result"]
    reason = llm_response_dict["reason"]

    # output the result of the evaluation
    if result != True and result != False:
        result = False
        reason = "LLM response does not contain a boolean value"
    return {"result": result, "reason": reason}


def is_email(output_to_test):
    return regex(output_to_test, r"^[a-zA-Z0-9_.+-]+@[a-zA-Z0-9-]+\.[a-zA-Z0-9-.]+$")


def is_phone_number(output_to_test):
    return regex(output_to_test, r"^\+?1?\d{9,15}$")


# Generated by chatGPT (regex might need some work)
def contains_email(output_to_test):
    return regex(output_to_test, r"[a-zA-Z0-9_.+-]+@[a-zA-Z0-9-]+\.[a-zA-Z0-9-.]+")


# Generated by chatGPT (regex might need some work)
def contains_phone_number(output_to_test):
    pattern = r"\+?\d{1,3}[-\s]?\(?\d{3}\)?[-\s]?\d{3}[-\s]?\d{2,4}|\(\d{3}\)\s?\d{3}[-\s]?\d{4}"
    return regex(output_to_test, pattern)


# Placeholder function to be replaced by an actual sentiment score function
def is_positive_sentiment(output_to_test):
    sentiment_grading_prompt = """
        If the string has a positive sentiment, then the test_result is True. Otherwise, it is false.
    """
    return grade_using_llm(
        output_to_test=output_to_test, eval_rubric=sentiment_grading_prompt
    )


# Placeholder function to be replaced by an actual sentiment score function
def is_negative_sentiment(output_to_test):
    sentiment_grading_prompt = """
        If the string has a negative sentiment, then the test passed. Otherwise, the test failed.
    """
    return grade_using_llm(
        output_to_test=output_to_test, eval_rubric=sentiment_grading_prompt
    )


def contains_pii(output_to_test):
    sentiment_grading_prompt = """
        If the string contains information that looks like personally identifiable information, then the test passed. Otherwise, the test failed.
    """
    return grade_using_llm(
        output_to_test=output_to_test, eval_rubric=sentiment_grading_prompt
    )


def not_contains_pii(output_to_test):
    sentiment_grading_prompt = """
        If the string contains information that looks like personally identifiable information, then the test failed. Otherwise, the test passed.
    """
    return grade_using_llm(
        output_to_test=output_to_test, eval_rubric=sentiment_grading_prompt
    )


def contains_link(output_to_test):
    pattern = r"(?!.*@)(?:https?://)?(?:www\.)?\S+\.\S+"
    result = bool(re.search(pattern, output_to_test))
    if result:
        return {"result": True, "reason": "Link found in output"}
    else:
        return {"result": False, "reason": "No link found in output"}


def contains_valid_link(output_to_test):
    pattern = r"(?!.*@)(?:https?://)?(?:www\.)?\S+\.\S+"
    link_match = re.search(pattern=pattern, string=output_to_test)
    if link_match:
        matched_url = link_match.group()
        if matched_url:
            standardized_url = standardize_url(matched_url)
            try:
                response = requests.head(standardized_url)
                if response.status_code == 200:
                    return {
                        "result": True,
                        "reason": f"link {matched_url} found in output and is valid",
                    }
                else:
                    return {
                        "result": False,
                        "reason": f"link {matched_url} found in output but is invalid",
                    }
            except:
                return {
                    "result": False,
                    "reason": f"link {matched_url} found in output but is invalid",
                }
    return {"result": False, "reason": f"no link found in output"}


def contains_credit_card_number(output_to_test):
    pattern = r"\b(?:\d[ -]*?){13,16}\b"
    result = bool(re.search(pattern, output_to_test))
    if result:
        return {"result": True, "reason": f"credit card number found in output"}
    else:
        return {"result": False, "reason": f"no credit card number found in output"}


def length_less_than(output_to_test, max_length):
    if len(output_to_test) < max_length:
        return {
            "result": True,
            "reason": f"output length is less than {max_length} characters",
        }
    else:
        return {
            "result": False,
            "reason": f"output length is greater than {max_length} characters",
        }


def length_greater_than(output_to_test, min_length):
    if len(output_to_test) > min_length:
        return {
            "result": True,
            "reason": f"output length is greater than {min_length} characters",
        }
    else:
        return {
            "result": False,
            "reason": f"output length is less than {min_length} characters",
        }


def is_json(output_to_test):
    try:
        json.loads(output_to_test)
        return {
            "result": True,
            "reason": f"output is valid json",
        }
    except ValueError:
        return {
            "result": False,
            "reason": f"output is not valid json",
        }


def contains_json(output_to_test):
    trimmed_output = output_to_test.strip()
    pattern = r"^\{.*\}$|^\[.*\]$"
    result = bool(re.search(pattern, trimmed_output, re.DOTALL))
    if result:
        return {
            "result": True,
            "reason": "Output contains JSON",
        }
    else:
        return {
            "result": False,
            "reason": "Output does not contain JSON",
        }



import os
from magik.internal_logger import logger
from magik.sys_exec import write_to_file
from magik.constants import (
    TESTRUNS_DIR,
    TEST_DIR,
    CONFIG_FILE_PATH,
)
from magik.sys_exec import read_from_file


# Create magik_tests directory
# Create magik_test_runs directory
# Create magik_config.json
def initialize():
    _create_magik_tests_dir()
    _create_magik_test_runs_dir()
    _create_magik_config_file()
    _add_config_file_to_gitignore()


def _create_magik_tests_dir():
    if not os.path.exists(TEST_DIR):
        os.makedirs(TEST_DIR, exist_ok=True)
        logger.info(f"✅ Created {TEST_DIR} directory")
    else:
        logger.info(f"{TEST_DIR} directory already exists")


def _create_magik_test_runs_dir():
    if not os.path.exists(TESTRUNS_DIR):
        os.makedirs(TESTRUNS_DIR, exist_ok=True)
        logger.info(f"✅ Created {TESTRUNS_DIR} directory")
    else:
        logger.info(f"{TESTRUNS_DIR} directory already exists")


def _create_magik_config_file():
    # Check if magik_config.json already exists
    if os.path.exists(CONFIG_FILE_PATH):
        logger.info(f"{CONFIG_FILE_PATH} already exists!")
        return

    # Create file magik_config.json
    logger.debug("Creating magik_config.json...")
    example_config_contents = """{
    "MAGIK_API_KEY": "",
    "OPEN_AI_API_KEY": "",
    "OPEN_AI_DEFAULT_MODEL": "gpt-3.5-turbo"
}"""
    write_to_file(
        CONFIG_FILE_PATH,
        example_config_contents,
    )

    logger.info(f"✅ Created {CONFIG_FILE_PATH} (config file)")
    logger.info("")
    logger.log_with_color(
        f"IMP: Please fill in the API keys in {CONFIG_FILE_PATH}", "yellow"
    )
    logger.info("")


def _add_config_file_to_gitignore():
    gitignore_path = ".gitignore"
    if not os.path.exists(gitignore_path):
        logger.info(f"{gitignore_path} does not exist!")
        logger.info(f"Make sure to add {CONFIG_FILE_PATH} to your gitignore file")
        return

    with open(gitignore_path, "a") as gitignore_file:
        gitignore_file.write("\n# Magik config file\nmagik_config.json\n")

    logger.info(f"✅ Added {CONFIG_FILE_PATH} to {gitignore_path}")



# API URLs
API_BASE_URL = "https://api.magiklabs.app"
DEPLOY_URL = f"{API_BASE_URL}/api/v1/testDeploy"
RUN_URL = f"{API_BASE_URL}/api/v1/testRun/group"

# Directory paths
TEST_DIR = "./magik_tests/tests"
TESTRUNS_DIR = "./magik_tests/test_runs"
CONFIG_FILE_PATH = f"./magik_tests/magik_config.json"
MAGIK_SDK_DIR = "./magik"  # TODO: This should come from the directory that one will have on running pip install magik
EXAMPLES_DIR = f"{MAGIK_SDK_DIR}/examples"
EXAMPLE_CONFIG_PATH = f"{EXAMPLES_DIR}/magik_config.example.json"

# Open AI defaults
OPEN_AI_DEFAULT_MODEL = "gpt-3.5-turbo"
